@@ -1,13 +1,13 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Control.Seq.Lens
--- Copyright   :  (C) 2012 Edward Kmett
+-- Copyright   :  (C) 2012-13 Edward Kmett
 -- License     :  BSD-style (see the file LICENSE)
 -- Maintainer  :  Edward Kmett <ekmett@gmail.com>
 -- Stability   :  provisional
 -- Portability :  portable
 --
--- A 'Fold' can be used to take the role of 'Foldable' in @Control.Seq@
+-- A 'Fold' can be used to take the role of 'Foldable' in @Control.Seq@.
 ----------------------------------------------------------------------------
 module Control.Seq.Lens
   ( seqOf
@@ -15,11 +15,12 @@ module Control.Seq.Lens
 
 import Control.Lens
 import Control.Seq
+import Data.Monoid
 
 -- | Evaluate the elements targeted by a 'Lens', 'Traversal', 'Iso',
 -- 'Getter' or 'Fold' according to the given strategy.
 --
 -- @'seqFoldable' = 'seqOf' 'folded'@
-seqOf :: Getting [c] a c -> Strategy c -> Strategy a
+seqOf :: Getting (Endo [a]) s t a b -> Strategy a -> Strategy s
 seqOf l s = seqList s . toListOf l
 {-# INLINE seqOf #-}
